summaryrefslogtreecommitdiffstats
path: root/models/status.go
diff options
context:
space:
mode:
Diffstat (limited to 'models/status.go')
-rw-r--r--models/status.go12
1 files changed, 4 insertions, 8 deletions
diff --git a/models/status.go b/models/status.go
index d0c4a08744..e2e8adb77b 100644
--- a/models/status.go
+++ b/models/status.go
@@ -71,15 +71,11 @@ type CommitStatus struct {
UpdatedUnix int64 `xorm:"INDEX updated"`
}
// AfterSet is invoked from XORM after setting the value of a field of
// this object.
-func (status *CommitStatus) AfterSet(colName string, _ xorm.Cell) {
- switch colName {
- case "created_unix":
- status.Created = time.Unix(status.CreatedUnix, 0).Local()
- case "updated_unix":
- status.Updated = time.Unix(status.UpdatedUnix, 0).Local()
- }
+func (status *CommitStatus) AfterLoad() {
+ status.Created = time.Unix(status.CreatedUnix, 0).Local()
+ status.Updated = time.Unix(status.UpdatedUnix, 0).Local()
}
func (status *CommitStatus) loadRepo(e Engine) (err error) {
@@ -71,15 +71,11 @@ type CommitStatus struct {
UpdatedUnix int64 `xorm:"INDEX updated"`
}
-// AfterSet is invoked from XORM after setting the value of a field of
+// AfterLoad is invoked from XORM after setting the value of a field of
// this object.